@@ -149,24 +149,51 @@ def add_nodes(parent_node, child_nodes):
 # will merge xml1 with xml2 and return a new xml comprising both of them.
 # NOTICE: this function will compare the direct root child nodes and merge/append them.
 def merge_xml1_with_xml2(xml1, xml2):
-    xml2_root = get_root_node(xml2)
-    xml2_direct_children = get_all_direct_child_nodes(xml2_root)
-    for xml1_child in get_all_direct_child_nodes(get_root_node(xml1)):
+    xml1_root = get_root_node(xml1)
+    xml1_direct_children = get_all_direct_child_nodes(xml1_root)
+    for xml2_child in get_all_direct_child_nodes(get_root_node(xml2)):
         parent_node = None
-        for xml2_child in xml2_direct_children:
+        for xml1_child in xml1_direct_children:
             # if the direct child already exists, add the appended tag content to the existing one
-            if xml1_child.tag == xml2_child.tag:
-                parent_node = xml2_child
+            if xml2_child.tag == xml1_child.tag:
+                parent_node = xml1_child
                 break
 
         if parent_node is not None:
-            xml1_direct_children = get_all_direct_child_nodes(xml1_child)
-            add_nodes(parent_node, xml1_direct_children)
-
+            xml2_direct_children = get_all_direct_child_nodes(xml2_child)
+            if len(xml2_direct_children) > 0:
+                add_nodes(parent_node, xml2_direct_children)
+            else:
+                # if reached here, it means that only the text is resembled
+                set_node_text(parent_node, f'{get_text_from_node(parent_node)}\n{get_text_from_node(xml2_child)}')
         else:
-            add_node(xml2_root, xml1_child)
+            add_node(xml1_root, xml2_child)
 
-    return xml2
+    return xml1
+#
+# # will merge xml1 with xml2 and return a new xml comprising both of them.
+# # NOTICE: this function will compare the direct root child nodes and merge/append them.
+# def merge_xml1_with_xml2(xml1, xml2):
+#     xml2_root = get_root_node(xml2)
+#     xml2_direct_children = get_all_direct_child_nodes(xml2_root)
+#     for xml1_child in get_all_direct_child_nodes(get_root_node(xml1)):
+#         parent_node = None
+#         for xml2_child in xml2_direct_children:
+#             # if the direct child already exists, add the appended tag content to the existing one
+#             if xml1_child.tag == xml2_child.tag:
+#                 parent_node = xml2_child
+#                 break
+#
+#         if parent_node is not None:
+#             xml1_direct_children = get_all_direct_child_nodes(xml1_child)
+#             if len(xml1_direct_children) > 0:
+#                 add_nodes(parent_node, xml1_direct_children)
+#             else:
+#                 set_node_text(parent_node, f'{get_text_from_node(xml1_child)}\n{get_text_from_node(parent_node)}')
+#         else:
+#             add_node(xml2_root, xml1_child)
+#
+#     return xml2
 
 
 # Will turn a simple dictionary to an xml file, by hierarchical order
